@@ -940,7 +940,10 @@ class account():
         words = tweet.split(" ")
         for word in words:
             if (word.startswith("@")):
-                word = " <span foreground = \"#0075b5\">" + word + "</span>"
+                if (word.endswith(".") | word.endswith(":")):
+                    word = " <span foreground = \"#0075b5\">" + word[0:len(word)-1] + "</span>" + word[len(word)-1:len(word)]
+                else:
+                    word = " <span foreground = \"#0075b5\">" + word + "</span>"
             if (word.startswith("http:")):
                 word = "<span foreground=\"#0075b5\">" + word + "</span>"
             if (word.startswith("witter") | word.startswith("Witter") | word.startswith("#witter") | word.startswith("#Witter")):
