@@ -877,28 +877,28 @@ class Witter():
                 self.ui.setWindowTitlePrefix("Witter(" + self.activeAccount.getUsername() + ")")
                 curView = self.ui.getCurrentView()
                 if (curView == self.ui.TIMELINE_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getTimeline())
+                    self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - timeline")
                 if (curView == self.ui.MENTIONS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getMentionsList())
+                    self.ui.setActiveListStore(self.activeAccount.getMentionsList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - mentions")
                 if (curView == self.ui.DM_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getDmsList())
+                    self.ui.setActiveListStore(self.activeAccount.getDmsList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - DMs")
                 if (curView == self.ui.SEARCH_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getSearchList())
+                    self.ui.setActiveListStore(self.activeAccount.getSearchList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - search")
                 if (curView == self.ui.FRIENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getFriendsList())
+                    self.ui.setActiveListStore(self.activeAccount.getFriendsList(),0)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - friends")
                 if (curView == self.ui.TRENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getTrendsList())
+                    self.ui.setActiveListStore(self.activeAccount.getTrendsList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - trends")
                 if (curView == self.ui.PUBLIC_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getPublicList())
+                    self.ui.setActiveListStore(self.activeAccount.getPublicList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - public")
                 if (curView == self.ui.USERHIST_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getUserHistoryList())
+                    self.ui.setActiveListStore(self.activeAccount.getUserHistoryList(),4)
                     self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - user history")
 
 
